### Description of Notebooks

#### 1) MIDI_MIR_Statistics.ipynb
##### This is a notebook for MIDI MIR and statistics. For now it only works on individual MIDIs.

#### 2) MIDI_Search.ipynb
##### This is a notebook for MIDI search/plagiarizm checking. For now it is a rather simple implementation which will be improved in the future.

***

##### Project Los Angeles

##### Tegridy Code 2021
